# 项目结构

- [项目结构](#项目结构)
  - [`.github`](#github)
    - [`.github/ISSUE_TEMPLATE`](#githubissue_template)
    - [`.github/workflows`](#githubworkflows)
    - [`.github/cliff.toml`](#githubclifftoml)
  - [`.vscode`](#vscode)
  - [`agent`](#agent)
    - [`agent/custom`](#agentcustom)
      - [`agent/custom/action`](#agentcustomaction)
      - [`agent/custom/reco`](#agentcustomreco)
    - [`agent/utils`](#agentutils)
    - [`agent/main.py`](#agentmainpy)
  - [`assets`](#assets)
    - [`assets/MaaCommonAssets`](#assetsmaacommonassets)
    - [`assets/resource`](#assetsresource)
      - [`assets/resource/base`](#assetsresourcebase)
        - [`assets/resource/base/image`](#assetsresourcebaseimage)
        - [`assets/resource/base/model`](#assetsresourcebasemodel)
        - [`assets/resource/base/pipeline`](#assetsresourcebasepipeline)
        - [`assets/resource/base/default_pipeline.json`](#assetsresourcebasedefault_pipelinejson)
      - [`assets/resource/bilibili`](#assetsresourcebilibili)
      - [`assets/resource/global_en`](#assetsresourceglobal_en)
      - [`assets/resource/global_jp`](#assetsresourceglobal_jp)
      - [`assets/resource/cn.json`](#assetsresourcecnjson)
      - [`assets/resource/en.json`](#assetsresourceenjson)
      - [`assets/resource/jp.json`](#assetsresourcejpjson)
    - [`assets/interface.json`](#assetsinterfacejson)
  - [`deps`](#deps)
  - [`docs`](#docs)
    - [`docs/zh_cn`](#docszh_cn)
      - [`docs/zh_cn/develop`](#docszh_cndevelop)
      - [`docs/zh_cn/manual`](#docszh_cnmanual)
    - [`docs/en_us`](#docsen_us)
      - [`docs/en_us/develop`](#docsen_usdevelop)
      - [`docs/en_us/manual`](#docsen_usmanual)
    - [`docs/.markdownlint.yaml`](#docsmarkdownlintyaml)
  - [`tools`](#tools)
    - [`tools/ci`](#toolsci)
    - [`tools/configure.py`](#toolsconfigurepy)
    - [`tools/install.py`](#toolsinstallpy)
  - [`.gitignore`](#gitignore)
  - [`.gitmodules`](#gitmodules)
  - [`.pre-commit-config.yaml`](#pre-commit-configyaml)
  - [`.prettierrc`](#prettierrc)
  - [`LICENSE`](#license)
  - [`package-lock.json&package.json`](#package-lockjsonpackagejson)
  - [`README.md`](#readmemd)
  - [`requirements.txt`](#requirementstxt)

以下为本项目项目结构及说明。

## `.github`

github 配置。

### `.github/ISSUE_TEMPLATE`

github issue 模板。

### `.github/workflows`

github 工作流配置。

### `.github/cliff.toml`

cliff 配置。（用于自动生成 release note）

## `.vscode`

vscode 配置。

## `agent`

存放 agent 相关代码。

### `agent/custom`

自定义动作/识别。

#### `agent/custom/action`

自定义动作。

#### `agent/custom/reco`

自定义识别。

### `agent/utils`

工具函数。

### `agent/main.py`

agent 启动前流程以及启动 AgentServer 。

## `assets`

存放项目资源文件。

### `assets/MaaCommonAssets`

存放 Maa 通用资源，如 OCR 模型。

### `assets/resource`

存放项目资源文件。

#### `assets/resource/base`

存放官服资源，且为其他服务器资源的覆盖基础。

##### `assets/resource/base/image`

存放模板图片。

##### `assets/resource/base/model`

存放 OCR 模型、神经网络分类模型、神经网络检测模型。[烹饪指南](https://github.com/MaaXYZ/MaaNeuralNetworkCookbook)

##### `assets/resource/base/pipeline`

json 文件，用于描述任务流水线，参考 [任务流水线协议](https://github.com/MaaXYZ/MaaFramework/blob/main/docs/zh_cn/3.1-%E4%BB%BB%E5%8A%A1%E6%B5%81%E6%B0%B4%E7%BA%BF%E5%8D%8F%E8%AE%AE.md) 编写。

##### `assets/resource/base/default_pipeline.json`

设置 pipeline 中默认属性，参考 [default_pipeline.json](https://github.com/MaaXYZ/MaaFramework/blob/main/sample/resource/default_pipeline.json)。

#### `assets/resource/bilibili`

存放B服资源，覆盖官服资源。

#### `assets/resource/global_en`

存放欧美服资源，依次覆盖官服、日服资源。

#### `assets/resource/global_jp`

存放日服资源，覆盖官方资源。

#### `assets/resource/cn.json`

存放 cn 服活动信息。

#### `assets/resource/en.json`

存放 en 服活动信息。

#### `assets/resource/jp.json`

存放 jp 服活动信息。

### `assets/interface.json`

MaaFramework 的一个标准化的项目结构声明，遵循[Project Interface 协议](https://github.com/MaaXYZ/MaaFramework/blob/main/docs/zh_cn/3.2-ProjectInterface%E5%8D%8F%E8%AE%AE.md)。

## `deps`

存放依赖。（将 MaaFramework Release 包下载后解压于此）

## `docs`

用户手册、开发文档。

### `docs/zh_cn`

中文文档。

#### `docs/zh_cn/develop`

开发文档。

#### `docs/zh_cn/manual`

用户手册。

### `docs/en_us`

英文文档。

#### `docs/en_us/develop`

英文开发文档。

#### `docs/en_us/manual`

英文用户手册。

### `docs/.markdownlint.yaml`

markdownlint 配置。

## `tools`

项目工具。

### `tools/ci`

仅在 ci 中会用到的工具。

### `tools/configure.py`

配置工具，将 MaaCommonAssets 复制到 resource 中。

### `tools/install.py`

安装工具，将源码和依赖组装后放入 `install` 目录。

## `.gitignore`

git 忽略清单。

## `.gitmodules`

git 子模块。

## `.pre-commit-config.yaml`

pre-commit 配置。

## `.prettierrc`

prettier 配置文件。

## `LICENSE`

开源许可证。

## `package-lock.json&package.json`

prettier 依赖。

## `README.md`

项目说明。

## `requirements.txt`

agent(python) 所需依赖。
